@@ -43,31 +43,27 @@ import java.util.Map;
 
 /**
  * <P>
- * PrimitiveHolderMap μǤ
- * ץߥƥַͤޥåԥ󥰤뤳ȤǤޤ
- * μϡޥåԥ󥰤줿ͤʸѴꡢʸͤѴޤ
- * 㤨СΤ褦˿ͤǼ塢ʸȤƼФȤǤޤ
+ * PrimitiveHolderMap ̎łB
+ * v~eBu^̒l}bsO邱Ƃł܂B
+ * ̎́A}bsOꂽl𕶎֕ϊA𐔒l֕ϊ܂B
+ * Ⴆ΁Â悤ɐli[AƂĎoƂł܂B
  * <PRE>
- *     map.setInt("someKey", 999);
+ *     map.putInt("someKey", 999);
  *     String value = map.getString("someKey");
  * </PRE>
- * ʸǼ塢ͤȤƼФȤǤޤ
+ * i[AlƂĎoƂł܂B
  * <PRE>
- *     map.setString("someKey", "999");
+ *     map.putString("someKey", "999");
  *     int value = map.getInt("someKey");
  * </PRE>
- * ʸǼ塢java.util.Date ȤƼФȤǤޤ
+ * ti[Ajava.util.Date ƂĎoƂł܂B
  * <PRE>
- *     map.setString("someKey", "2003/04/01");
+ *     map.putString("someKey", "2003/04/01");
  *     java.util.Date value = map.getDate("someKey");
  * </PRE>
  * </P>
  * <P>
- * Τ褦ͤѴǽϡWeb ڡեǡʸǼ褦 Web ץꥱǤϡäͭǤ
- * </P>
- * <P>
- * μϡͤϢդ륭 String ξ硢ʸʸ̤ޤ
- *  String ξ硢٤ƾʸѴޤ
+ * ̂悤Ȓl̕ϊ@\́AWeb y[WtH[f[^𕶎Ŏ󂯎悤 Web AvP[Vł́AɗLłB
  * </P>
  * @author Kenichi Fukuda
  */
@@ -75,25 +71,25 @@ public class ConversionMap
 	extends MapWrapper
 	implements PrimitiveHolderMap, Serializable
 {
-	//null  String 
+	//null  String ^̒l
 	private static final String NULL_STRING = "";
 
 	/**
 	 * <P>
-	 * ConversionMap ۤơΥޥåפ餹٤ƤΥޥåԥ󥰤 ConversionMap ˥ԡޤ
+	 * w̃}bvbv ConversionMap \z܂B
 	 * </P>
-	 * @param map åפޥå
-	 * @exception IllegalArgumentException ޥåפ null ξ
+	 * @param map bv}bv
+	 * @exception IllegalArgumentException }bv null ̏ꍇ
 	 */
-	protected ConversionMap(java.util.Map map)
+	public ConversionMap(java.util.Map map)
 	{
-		this();
-		putAll(map);
+		super(map);
 	}
 
 	/**
 	 * <P>
-	 * ConversionMap ۤޤ
+	 * ConversionMap \z܂B
+	 * HashMap bvV ConversionMap \z܂B
 	 * </P>
 	 */
 	public ConversionMap()
@@ -103,19 +99,15 @@ public class ConversionMap
 
 	private Object getKey(Object key)
 	{
-		if (key instanceof String)
-		{
-			return ((String)key).toLowerCase();
-		}
 		return key;
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤϥȥ꡼ȤƼޤ
+	 * }bvw̃L[}bvl̓Xg[ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getInputStream(Object)
 	 */
 	public synchronized InputStream getInputStream(Object key)
@@ -125,23 +117,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * ϥȥ꡼ޥåλΥȴϢդޤ
+	 * w̓̓Xg[}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setInputStream(Object, InputStream)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putInputStream(Object, InputStream)
 	 */
-	public synchronized void setInputStream(Object key, InputStream value)
+	public synchronized void putInputStream(Object key, InputStream value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ java.math.BigDecimal ֥ȤȤƼޤ
+	 * }bvw̃L[}bvl java.math.BigDecimal IuWFNgƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getBigDecimal(Object)
 	 */
 	public synchronized BigDecimal getBigDecimal(Object key)
@@ -167,23 +159,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  java.math.BigDecimal ֥ȤޥåλΥȴϢդޤ
+	 * w java.math.BigDecimal IuWFNg}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setBigDecimal(Object, BigDecimal)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putBigDecimal(Object, BigDecimal)
 	 */
-	public synchronized void setBigDecimal(Object key, BigDecimal value)
+	public synchronized void putBigDecimal(Object key, BigDecimal value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ java.math.BigInteger ֥ȤȤƼޤ
+	 * }bvw̃L[}bvl java.math.BigInteger IuWFNgƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getBigInteger(Object)
 	 */
 	public synchronized BigInteger getBigInteger(Object key)
@@ -209,23 +201,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  java.math.BigInteger ֥ȤޥåλΥȴϢդޤ
+	 * w java.math.BigInteger IuWFNg}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setBigInteger(Object, BigInteger)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putBigInteger(Object, BigInteger)
 	 */
-	public synchronized void setBigInteger(Object key, BigInteger value)
+	public synchronized void putBigInteger(Object key, BigInteger value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 boolean ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O boolean ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getBoolean(Object)
 	 */
 	public synchronized boolean getBoolean(Object key)
@@ -249,23 +241,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  boolean ͤޥåλΥȴϢդޤ
+	 * w boolean l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setBoolean(Object, boolean)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putBoolean(Object, boolean)
 	 */
-	public synchronized void setBoolean(Object key, boolean value)
+	public synchronized void putBoolean(Object key, boolean value)
 	{
 		put(key, new Boolean(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 byte ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O byte ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getByte(Object)
 	 */
 	public synchronized byte getByte(Object key)
@@ -291,23 +283,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  byte ͤޥåλΥȴϢդޤ
+	 * w byte l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setByte(Object, byte)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putByte(Object, byte)
 	 */
-	public synchronized void setByte(Object key, byte value)
+	public synchronized void putByte(Object key, byte value)
 	{
 		put(key, new Byte(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 byte ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O byte zƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getBytes(Object)
 	 */
 	public synchronized byte[] getBytes(Object key)
@@ -317,23 +309,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  byte ޥåλΥȴϢդޤ
+	 * w byte z}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setBytes(Object, byte[])
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putBytes(Object, byte[])
 	 */
-	public synchronized void setBytes(Object key, byte[] value)
+	public synchronized void putBytes(Object key, byte[] value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 char ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O char ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getChar(Object)
 	 */
 	public synchronized char getChar(Object key)
@@ -359,23 +351,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  char ͤޥåλΥȴϢդޤ
+	 * w char l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setChar(Object, char)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putChar(Object, char)
 	 */
-	public synchronized void setChar(Object key, char value)
+	public synchronized void putChar(Object key, char value)
 	{
 		put(key, new Character(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ java.io.Reader ֥ȤȤƼޤ
+	 * }bvw̃L[}bvl java.io.Reader IuWFNgƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getReader(Object)
 	 */
 	public synchronized Reader getReader(Object key)
@@ -385,23 +377,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  java.io.Reader ֥ȤޥåλΥȴϢդޤ
+	 * w java.io.Reader IuWFNg}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setReader(Object, Reader)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putReader(Object, Reader)
 	 */
-	public synchronized void setReader(Object key, Reader value)
+	public synchronized void putReader(Object key, Reader value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ java.util.Date ֥ȤȤƼޤ
+	 * }bvw̃L[}bvl java.util.Date IuWFNgƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getDate(Object)
 	 */
 	public synchronized Date getDate(Object key)
@@ -415,27 +407,27 @@ public class ConversionMap
 
 		if (obj instanceof java.sql.Timestamp)
 		{
-			//java.sql.Timestamp ֥Ȥξ
+			//java.sql.Timestamp IuWFNg̏ꍇ
 			return new java.util.Date(((java.sql.Timestamp)obj).getTime());
 		}
 		else if (obj instanceof java.sql.Date)
 		{
-			//java.sql.Date ֥Ȥξ
+			//java.sql.Date IuWFNg̏ꍇ
 			return new java.util.Date(((java.sql.Date)obj).getTime());
 		}
 		else if (obj instanceof java.sql.Time)
 		{
-			//java.sql.Time ֥Ȥξ
+			//java.sql.Time IuWFNg̏ꍇ
 			return new java.util.Date(((java.sql.Time)obj).getTime());
 		}
 		else if (obj instanceof java.util.Date)
 		{
-			//java.util.Date ֥Ȥξ
+			//java.util.Date IuWFNg̏ꍇ
 			return (java.util.Date)obj;
 		}
 		else
 		{
-			//java.sql.Timestamp ʸɽξ
+			//java.sql.Timestamp ̕\̏ꍇ
 			try
 			{
 				return new java.util.Date(java.sql.Timestamp.valueOf(obj.toString()).getTime());
@@ -444,7 +436,7 @@ public class ConversionMap
 			{
 			}
 
-			//java.sql.Date ʸɽξ
+			//java.sql.Date ̕\̏ꍇ
 			try
 			{
 				return new java.util.Date(java.sql.Date.valueOf(obj.toString()).getTime());
@@ -453,7 +445,7 @@ public class ConversionMap
 			{
 			}
 
-			//java.sql.Time ʸɽξ
+			//java.sql.Time ̕\̏ꍇ
 			try
 			{
 				return new java.util.Date(java.sql.Time.valueOf(obj.toString()).getTime());
@@ -462,7 +454,7 @@ public class ConversionMap
 			{
 			}
 
-			//java.util.Date ʸɽξ
+			//java.util.Date ̕\̏ꍇ
 			try
 			{
 				return new SimpleDateFormat(
@@ -473,7 +465,7 @@ public class ConversionMap
 			{
 			}
 
-			///ʸɽξ
+			//t/̕\̏ꍇ
 			try
 			{
 				return DateFormat.getDateTimeInstance().parse(obj.toString());
@@ -482,7 +474,7 @@ public class ConversionMap
 			{
 			}
 
-			//դʸɽξ
+			//t̕\̏ꍇ
 			try
 			{
 				return DateFormat.getDateInstance().parse(obj.toString());
@@ -491,7 +483,7 @@ public class ConversionMap
 			{
 			}
 
-			//ʸɽξ
+			//̕\̏ꍇ
 			try
 			{
 				return DateFormat.getTimeInstance().parse(obj.toString());
@@ -506,11 +498,11 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤʸɽ pattern ǻꤷաѥǲϤơjava.util.Date ֥ȤȤƼޤ
+	 * }bvw̃L[}bvl̕\ pattern Ŏw肵t^p^[ŉ͂āAjava.util.Date IuWFNgƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @param pattern աѥ
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @param pattern t^p^[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#parseDate(Object, String)
 	 */
 	public synchronized Date parseDate(Object key, String pattern)
@@ -535,23 +527,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  java.util.Date ͤޥåλΥȴϢդޤ
+	 * w java.util.Date l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setDate(Object, Date)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putDate(Object, Date)
 	 */
-	public synchronized void setDate(Object key, Date value)
+	public synchronized void putDate(Object key, Date value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 double ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O double ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getDouble(Object)
 	 */
 	public synchronized double getDouble(Object key)
@@ -577,23 +569,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  double ͤޥåλΥȴϢդޤ
+	 * w double l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setDouble(Object, double)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putDouble(Object, double)
 	 */
-	public synchronized void setDouble(Object key, double value)
+	public synchronized void putDouble(Object key, double value)
 	{
 		put(key, new Double(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 float ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O float ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getFloat(Object)
 	 */
 	public synchronized float getFloat(Object key)
@@ -619,23 +611,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  float ͤޥåλΥȴϢդޤ
+	 * w float l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setFloat(Object, float)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putFloat(Object, float)
 	 */
-	public synchronized void setFloat(Object key, float value)
+	public synchronized void putFloat(Object key, float value)
 	{
 		put(key, new Float(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 int ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O int ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getInt(Object)
 	 */
 	public synchronized int getInt(Object key)
@@ -661,23 +653,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  int ͤޥåλΥȴϢդޤ
+	 * w int l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setInt(Object, int)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putInt(Object, int)
 	 */
-	public synchronized void setInt(Object key, int value)
+	public synchronized void putInt(Object key, int value)
 	{
 		put(key, new Integer(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 long ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O long ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getLong(Object)
 	 */
 	public synchronized long getLong(Object key)
@@ -703,23 +695,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  long ͤޥåλΥȴϢդޤ
+	 * w long l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setLong(Object, long)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putLong(Object, long)
 	 */
-	public synchronized void setLong(Object key, long value)
+	public synchronized void putLong(Object key, long value)
 	{
 		put(key, new Long(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 Object ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O Object ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getObject(Object)
 	 */
 	public synchronized Object getObject(Object key)
@@ -729,23 +721,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  Object ͤޥåλΥȴϢդޤ
+	 * w Object l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setObject(Object, Object)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putObject(Object, Object)
 	 */
-	public synchronized void setObject(Object key, Object value)
+	public synchronized void putObject(Object key, Object value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 short ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O short ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getShort(Object)
 	 */
 	public synchronized short getShort(Object key)
@@ -771,23 +763,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  short ͤޥåλΥȴϢդޤ
+	 * w short l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setShort(Object, short)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putShort(Object, short)
 	 */
-	public synchronized void setShort(Object key, short value)
+	public synchronized void putShort(Object key, short value)
 	{
 		put(key, new Short(value));
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥޥåפͤ Java ץߥ󥰸 String ȤƼޤ
+	 * }bvw̃L[}bvl Java vO~O String ƂĎ擾܂B
 	 * </P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿ޥåפ
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
 	 * @see jp.morpho.util.PrimitiveHolderMap#getString(Object)
 	 */
 	public synchronized String getString(Object key)
@@ -811,23 +803,23 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 *  String ͤޥåλΥȴϢդޤ
+	 * w String l}bv̎w̃L[Ɗ֘At܂B
 	 * </P>
-	 * @param key ꤵ줿ͤϢդ륭
-	 * @param value ꤵ줿˴Ϣդ
-	 * @see jp.morpho.util.PrimitiveHolderMap#setString(Object, String)
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putString(Object, String)
 	 */
-	public synchronized void setString(Object key, String value)
+	public synchronized void putString(Object key, String value)
 	{
 		put(key, value);
 	}
 
 	/**
 	 * <P>
-	 *  ConversionMap ۤơΥޥåפ餹٤ƤΥޥåԥ󥰤ۤ  ConversionMap ˥ԡޤ
-	 * Υޥåפ ConversionMap ξϡ֤ޤ
+	 * V ConversionMap \zāAw̃}bv炷ׂẴ}bsO\zV  ConversionMap ɃRs[܂B
+	 * w̃}bv ConversionMap ̏ꍇ́AԂ܂B
 	 * </P>
-	 * @param map ۤ ConversionMap ˳Ǽޥåԥ
+	 * @param map V\z ConversionMap Ɋi[}bsO
 	 * @return ConversionMap
 	 */
 	public synchronized static ConversionMap valueOf(Map map)
@@ -844,22 +836,29 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * ꤵ줿˥ޥåפƤͤξ true ֤ޤ
+	 * w肳ꂽL[Ƀ}bvĂlz̏ꍇ true Ԃ܂B
 	 * </P>
-	 * @param key ޥåפƤͤǤ뤫ɤȽꤵ륭
-	 * @return ꤵ줿˥ޥåפƤͤξ true
+	 * @param key }bvĂlzł邩ǂ肳L[
+	 * @return w肳ꂽL[Ƀ}bvĂlz̏ꍇ true
 	 */
 	public synchronized boolean isArray(Object key)
 	{
+		Object obj = get(key);
+
+		if (obj == null)
+		{
+			return false;
+		}
+
 		return this.getObject(key).getClass().isArray();
 	}
 
 	/**
 	 * <P>
-	 * ޥåפΥΥޥåԥ󥰤ݻ true ֤ޤ
+	 * }bvw̃L[̃}bsOێꍇ true Ԃ܂B
 	 * </P>
-	 * @param key ޥåפˤ뤫ɤȽꤵ륭
-	 * @return ޥåפΥΥޥåԥ󥰤ݻ true
+	 * @param key }bvɂ邩ǂ肳L[
+	 * @return }bvw̃L[̃}bsOێꍇ true
 	 * @see java.util.Map#containsKey(Object)
 	 */
 	public boolean containsKey(Object key)
@@ -869,14 +868,14 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * Υޥåפǻꤵ줿˥ޥåפƤ֤ͤޤ
-	 * ޥåפΥΥޥåԥ󥰤ݻƤʤ null ֤ޤ
-	 * ͤ null ϡޥåפΥޥåԥ󥰤ݻƤʤȤ򼨤ȤϤޤ
-	 * ĤޤꡢޥåפŪ˥ null ˥ޥåפ뤳Ȥ⤢ޤ
-	 * containsKey(Object) ᥽åɤȤȡ 2 Ĥξʬ뤳ȤǤޤ
+	 * ̃}bvŎw肳ꂽL[Ƀ}bvĂlԂ܂B
+	 * }bṽL[̃}bsOێĂȂꍇ null Ԃ܂B
+	 * ߂l null ́A}bvL[̃}bsOێĂȂƂƂ͂܂B
+	 * ܂A}bvIɃL[ null Ƀ}bv邱Ƃ܂B
+	 * containsKey(Object) \bhgƁA 2 ̏ꍇ邱Ƃł܂B
 	 * <P>
-	 * @param key Ϣդ줿֤ͤ륭
-	 * @return ޥåפꤵ줿˥ޥåԥ󥰤Ƥ͡ΥФޥåԥ󥰤ޥåפˤʤ  null
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvAw肳ꂽL[Ƀ}bsOĂlB̃L[ɑ΂}bsO}bvɂȂꍇ  null
 	 * @see java.util.Map#get(Object)
 	 */
 	public Object get(Object key)
@@ -886,12 +885,12 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * ͤȻꤵ줿򤳤Υޥåפ˴Ϣդޤ
-	 * ޥåפˤΥΥޥåԥ󥰤ݻƤ硢Ť֤ͤޤ
+	 * w̒lƎw肳ꂽL[̃}bvɊ֘At܂B
+	 * }bvȑOɂ̃L[̃}bsOێĂꍇAÂlu܂B
 	 * <P>
-	 * @param key ꤵͤϢդ륭
-	 * @param value ꤵ륭˴Ϣդ
-	 * @return ꤵ줿˴Ϣ͡ޤϡΥޥåԥ󥰤ʤä null null ϡConversionMap  null Ȼꤵ줿ϢդƤȤ򼨤⤢
+	 * @param key w肳l֘AtL[
+	 * @param value w肳L[Ɋ֘Atl
+	 * @return w肳ꂽL[Ɋ֘AlB܂́AL[̃}bsOȂꍇ nullB߂l null ́AConversionMap ȑO null Ǝw肳ꂽL[֘AtĂƂꍇ
 	 * @see java.util.Map#put(Object, Object)
 	 */
 	public Object put(Object key, Object value)
@@ -901,10 +900,10 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * Υޥåפ餹٤ƤΥޥåԥ󥰤ޥåפ˥ԡޤ
-	 * ˤꡢޥåפΥޥå˸ߤ륭Τ٤ƤФƻäƤޥåԥ󥰤֤ޤ
+	 * w̃}bv炷ׂẴ}bsO}bvɃRs[܂B
+	 * ɂA}bvw̃}bvɌ݂L[ׂ̂Ăɑ΂ĎĂ}bsOu܂B
 	 * <P>
-	 * @param map ޥåפ˳Ǽޥåԥ
+	 * @param map }bvɊi[}bsO
 	 * @see java.util.Map#putAll(Map)
 	 */
 	public void putAll(Map map)
@@ -918,10 +917,10 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * Фޥåԥ󥰤СΥޥåפޤ
+	 * L[ɑ΂}bsO΁ÃL[}bv폜܂B
 	 * <P>
-	 * @param key ޥåԥ󥰤ޥåפ륭
-	 * @return ꤵ줿˴Ϣ͡ޤϡΥޥåԥ󥰤ʤä null null ϡޥåפ null Ȼꤵ줿ϢդƤȤ򼨤⤢
+	 * @param key }bsO}bv폜L[
+	 * @return w肳ꂽL[Ɋ֘AlB܂́AL[̃}bsOȂꍇ nullB߂l null ́A}bvȑO null Ǝw肳ꂽL[֘AtĂƂꍇ
 	 * @see java.util.Map#remove(Object)
 	 */
 	public Object remove(Object key)
@@ -931,14 +930,66 @@ public class ConversionMap
 
 	/**
 	 * <P>
-	 * ꤵ줿˥ޥåפƤͤ NULL ξ true ֤ޤ
+	 * w肳ꂽL[Ƀ}bvĂl NULL ̏ꍇ true Ԃ܂B
 	 * </P>
-	 * @param key ޥåפƤͤ NULL Ǥ뤫ɤȽꤵ륭
-	 * @return ꤵ줿˥ޥåפƤͤ NULL ξ true
+	 * @param key }bvĂl NULL ł邩ǂ肳L[
+	 * @return w肳ꂽL[Ƀ}bvĂl NULL ̏ꍇ true
 	 */
 	public synchronized boolean isNull(Object key)
 	{
 		return ((this.getObject(key) == null) ? true : false);
 	}
 
+	/**
+	 * <P>
+	 * }bvw̃L[}bvl java.util.List ƂĎ擾܂B
+	 * </P>
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
+	 * @see jp.morpho.util.PrimitiveHolderMap#getList(Object)
+	 */
+	public synchronized java.util.List getList(Object key)
+	{
+		return (java.util.List)get(key);
+	}
+
+	/**
+	 * <P>
+	 * w java.util.List }bv̎w̃L[Ɗ֘At܂B
+	 * </P>
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putList(Object, List)
+	 */
+	public synchronized void putList(Object key, java.util.List value)
+	{
+		put(key, value);
+	}
+
+	/**
+	 * <P>
+	 * }bvw̃L[}bvl java.util.Map ƂĎ擾܂B
+	 * </P>
+	 * @param key ֘AtꂽlԂL[
+	 * @return }bvw肳ꂽL[}bvl
+	 * @see jp.morpho.util.PrimitiveHolderMap#getMap(Object)
+	 */
+	public synchronized java.util.Map getMap(Object key)
+	{
+		return (java.util.Map)get(key);
+	}
+
+	/**
+	 * <P>
+	 * w java.util.Map }bv̎w̃L[Ɗ֘At܂B
+	 * </P>
+	 * @param key w肳ꂽl֘AtL[
+	 * @param value w肳ꂽL[Ɋ֘Atl
+	 * @see jp.morpho.util.PrimitiveHolderMap#putMap(Object, Map)
+	 */
+	public synchronized void putMap(Object key, java.util.Map value)
+	{
+		put(key, value);
+	}
+
 }
